bayespy.inference.vmp.nodes.gaussian.GaussianWishartMoments.compute_fixed_moments
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartMoments.compute_fixed_moments